@@ -31,8 +31,11 @@ public:
     /// Others     :ͨGetApiErrorMsg(nResult)ȡϸϢ
     virtual void OnFrontDisconnected(int nResult){};
 
-	/// Description:ͻ֤
-	virtual void OnRspAuthenticate(CHSRspAuthenticateField *pRspAuthenticate, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+    /// Description:ͻ֤
+    virtual void OnRspAuthenticate(CHSRspAuthenticateField *pRspAuthenticate, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:նϢϱӿ(мģʽ)
+    virtual void OnRspSubmitUserSystemInfo(CHSRspUserSystemInfoField *pRspUserSystemInfo, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
     /// Description:ͻ¼
     virtual void OnRspUserLogin(CHSRspUserLoginField *pRspUserLogin, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
@@ -68,11 +71,14 @@ public:
     virtual void OnRspQueryMaxOrderVolume(CHSRspQueryMaxOrderVolumeField *pRspQueryMaxOrderVolume, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
     /// Description:ȡ
-    virtual void OnRspQueryLockVolume(CHSRspQueryLockVolumeField *pRspQueryLockVolume, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+    virtual void OnRspQryLockVolume(CHSRspQryLockVolumeField *pRspQryLockVolume, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
     /// Description:Ȩȡ
     virtual void OnRspQueryExerciseVolume(CHSRspQueryExerciseVolumeField *pRspQueryExerciseVolume, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
+    /// Description:ȡ
+    virtual void OnRspQryCombVolume(CHSRspQryCombVolumeField *pRspQryCombVolume, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
     /// Description:ֲֲѯ
     virtual void OnRspQryPosition(CHSRspQryPositionField *pRspQryPosition, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
@@ -118,6 +124,9 @@ public:
     /// Description:˻ѯ
     virtual void OnRspQueryBankAccount(CHSRspQueryBankAccountField *pRspQueryBankAccount, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
+    /// Description:ʽ
+    virtual void OnRspMultiCentreFundTrans(CHSRspMultiCentreFundTransField *pRspMultiCentreFundTransfer, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
     /// Description:ͻ˵ѯ
     virtual void OnRspQueryBillContent(CHSRspQueryBillContentField *pRspQueryBillContent, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
@@ -133,7 +142,7 @@ public:
     /// Description:ֲϸѯ
     virtual void OnRspQryPositionDetail(CHSRspQryPositionDetailField *pRspQryPositionDetail, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
-    // Description:ʲѯ
+    /// Description:ʲѯ
     virtual void OnRspQryExchangeRate(CHSRspQryExchangeRateField *pRspQryExchangeRate, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
     /// Description:͹˾òѯ
@@ -142,6 +151,27 @@ public:
     /// Description:ѯ
     virtual void OnRspQryDepthMarketData(CHSDepthMarketDataField *pRspQryDepthMarketData, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
 
+    /// Description:ʽ
+    virtual void OnRspFundTrans(CHSRspFundTransField *pRspFundTransfer, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:ʽˮѯ
+    virtual void OnRspQryFundTrans(CHSRspQryFundTransField *pRspQryFundTrans, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:ѯͻ֪ͨ
+    virtual void OnRspQryClientNotice(CHSClientNoticeField *pRspQryClientNotice, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:ȨϢѯ
+    virtual void OnRspQryOptUnderly(CHSRspQryOptUnderlyField *pRspQryOptUnderly, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:֤ȯѯ
+    virtual void OnRspQrySecuDepthMarket(CHSRspQrySecuDepthMarketField *pRspQrySecuDepthMarket, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:ʷѯ
+    virtual void OnRspQryHistOrder(CHSOrderField *pRspQryHistOrder, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
+    /// Description:ʷɽѯ
+    virtual void OnRspQryHistTrade(CHSTradeField *pRspQryHistTrade, CHSRspInfoField *pRspInfo, int nRequestID, bool bIsLast){};
+
     /// Description: -ɽر
     virtual void OnRtnTrade(CHSTradeField *pRtnTrade) {};
 
@@ -156,6 +186,12 @@ public:
 
     /// Description: -
     virtual void OnRtnLock(CHSLockField *pRtnLock) {};
+
+    /// Description: -ر
+    virtual void OnErrRtnOrderAction(CHSOrderActionField *pRtnOrder) {};
+
+    /// Description: -ͻ֪ͨ
+    virtual void OnRtnClientNotice(CHSClientNoticeField *pRtnClientNotice) {};
 };
 
 ///
@@ -179,10 +215,10 @@ public:
 
     /// Description: עᶩģʽδ֧֣
     /// Input      : ķʽ
-    ///                 HS_TERT_RESTART://ӱտʼش
-    ///                 HS_TERT_RESUME: //ϴյ
-    ///                 HS_TERT_QUICK:  //ӵ¼µĿʼ
-    virtual int RegisterSubModel(const char *pszSubModel) = 0;
+    ///               HS_TERT_RESTART://ӱտʼش
+    ///               HS_TERT_RESUME: //ϴյ
+    ///               HS_TERT_QUICK:  //ӵ¼µĿʼ
+    virtual int RegisterSubModel(SUB_TERT_TYPE eSubType) = 0;
 
     /// Description: עǰûַ
     /// Input      : pszFrontAddress           ǰûַ 磺tcp://127.0.0.1:17001
@@ -208,6 +244,9 @@ public:
     /// Description: ֤ 
     virtual int ReqAuthenticate(CHSReqAuthenticateField *pReqAuthenticate,int nRequestID) = 0;
 
+    /// Description: նϢϱӿ(мģʽ)
+    virtual int ReqSubmitUserSystemInfo(CHSReqUserSystemInfoField *pReqUserSystemInfo,int nRequestID) = 0;
+
     /// Description:ͻ¼
     virtual int  ReqUserLogin(CHSReqUserLoginField *pReqUserLogin, int nRequestID) = 0;
 
@@ -239,11 +278,14 @@ public:
     virtual int  ReqQueryMaxOrderVolume(CHSReqQueryMaxOrderVolumeField *pReqQueryMaxOrderVolume, int nRequestID) = 0;
 
     /// Description:ȡ
-    virtual int  ReqQueryLockVolume(CHSReqQueryLockVolumeField *pReqQueryLockVolume, int nRequestID) = 0;
+    virtual int  ReqQryLockVolume(CHSReqQryLockVolumeField *pReqQryLockVolume, int nRequestID) = 0;
 
     /// Description:Ȩȡ
     virtual int  ReqQueryExerciseVolume(CHSReqQueryExerciseVolumeField *pReqQueryExerciseVolume, int nRequestID) = 0;
 
+    /// Description:ȡ
+    virtual int  ReqQryCombVolume(CHSReqQryCombVolumeField *pReqQryCombVolume, int nRequestID) = 0;
+
     /// Description:ֲֻܲѯ
     virtual int  ReqQryPosition(CHSReqQryPositionField *pReqQryPosition, int nRequestID) = 0;
 
@@ -289,6 +331,9 @@ public:
     /// Description:˻ѯ
     virtual int  ReqQueryBankAccount(CHSReqQueryBankAccountField *pReqQueryBankAccount, int nRequestID) = 0;
 
+    /// Description:ʽ
+    virtual int  ReqMultiCentreFundTrans(CHSReqMultiCentreFundTransField *pReqMultiCentreFundTransfer, int nRequestID) = 0;
+
     /// Description:ͻ˵ѯ
     virtual int  ReqQueryBillContent(CHSReqQueryBillContentField *pReqQueryBillContent, int nRequestID) = 0;
 
@@ -301,8 +346,8 @@ public:
     /// Description:Ѳѯ
     virtual int  ReqQryCommission(CHSReqQryCommissionField *pReqQryCommission, int nRequestID) = 0;
 
-	/// Description:ʲѯ
-	virtual int  ReqQryExchangeRate(CHSReqQryExchangeRateField *pReqQryExchangeRate, int nRequestID) = 0;
+    /// Description:ʲѯ
+    virtual int  ReqQryExchangeRate(CHSReqQryExchangeRateField *pReqQryExchangeRate, int nRequestID) = 0;
 
     /// Description:ֲϸѯ
     virtual int  ReqQryPositionDetail(CHSReqQryPositionDetailField *pReqQryPositionDetail, int nRequestID) = 0;
@@ -312,6 +357,27 @@ public:
 
     /// Description:ѯ
     virtual int  ReqQryDepthMarketData(CHSReqQryDepthMarketDataField *pReqQryDepthMarketData, int nRequestID) = 0;
+
+    /// Description:ʽ
+    virtual int  ReqFundTrans(CHSReqFundTransField *pReqFundTransfer, int nRequestID) = 0;
+
+    /// Description:ʽˮѯ
+    virtual int  ReqQryFundTrans(CHSReqQryFundTransField *pReqQryFundTrans, int nRequestID) = 0;
+
+    /// Description:ͻ֪ͨѯ
+    virtual int  ReqQryClientNotice(CHSReqQryClientNoticeField *pReqQryClientNotice, int nRequestID) = 0;
+
+    /// Description:ȨϢѯ
+    virtual int  ReqQryOptUnderly(CHSReqQryOptUnderlyField *pReqQryOptUnderly, int nRequestID) = 0;
+
+    /// Description:֤ȯѯ
+    virtual int  ReqQrySecuDepthMarket(CHSReqQrySecuDepthMarketField *pReqQrySecuDepthMarket, int nRequestID) = 0;
+
+    /// Description:ʷѯ
+    virtual int  ReqQryHistOrder(CHSReqQryHistOrderField *pReqQryHistOrder, int nRequestID) = 0;
+
+    /// Description:ʷɽѯ
+    virtual int  ReqQryHistTrade(CHSReqQryHistTradeField *pReqQryHistTrade, int nRequestID) = 0;
 protected:
     ~CHSTradeApi(){};
 };
